@@ -51,18 +51,18 @@
 
 #include <kcursor.h>
 #include <kurllabel.h>
-#include <klocale.h>
-#include <kaboutdata.h>
+#include <tdelocale.h>
+#include <tdeaboutdata.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kapplication.h>
-#include <kpopupmenu.h>
-#include <kfiledialog.h>
+#include <tdeapplication.h>
+#include <tdepopupmenu.h>
+#include <tdefiledialog.h>
 #include <kstandarddirs.h>
 #include <kprogress.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <kpassivepopup.h>
 
 // Local includes.
@@ -134,11 +134,11 @@ ImageEffect_InPainting_Dialog::ImageEffect_InPainting_Dialog(TQWidget* parent)
     m_isComputed = false;
     TQString whatsThis;
 
-    KAboutData* about = new KAboutData("digikam",
+    TDEAboutData* about = new TDEAboutData("digikam",
                                        I18N_NOOP("Photograph Inpainting"),
                                        digikam_version,
                                        I18N_NOOP("A digiKam image plugin to inpaint a photograph."),
-                                       KAboutData::License_GPL,
+                                       TDEAboutData::License_GPL,
                                        "(c) 2005-2008, Gilles Caulier",
                                        0,
                                        "http://www.digikam.org");
@@ -167,8 +167,8 @@ ImageEffect_InPainting_Dialog::ImageEffect_InPainting_Dialog(TQWidget* parent)
     KURLLabel *cimgLogoLabel = new KURLLabel(firstPage);
     cimgLogoLabel->setText(TQString());
     cimgLogoLabel->setURL("http://cimg.sourceforge.net");
-    KGlobal::dirs()->addResourceType("logo-cimg", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("logo-cimg", "logo-cimg.png");
+    TDEGlobal::dirs()->addResourceType("logo-cimg", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("logo-cimg", "logo-cimg.png");
     cimgLogoLabel->setPixmap( TQPixmap( directory + "logo-cimg.png" ) );
     TQToolTip::add(cimgLogoLabel, i18n("Visit CImg library website"));
 
@@ -218,7 +218,7 @@ void ImageEffect_InPainting_Dialog::renderingFinished()
 
 void ImageEffect_InPainting_Dialog::readUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("inpainting Tool Dialog");
 
     Digikam::GreycstorationSettings settings;
@@ -249,7 +249,7 @@ void ImageEffect_InPainting_Dialog::readUserSettings()
 void ImageEffect_InPainting_Dialog::writeUserSettings()
 {
     Digikam::GreycstorationSettings settings = m_settingsWidget->getSettings();
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("inpainting Tool Dialog");
     config->writeEntry("Preset", m_inpaintingTypeCB->currentItem());
     config->writeEntry("FastApprox", settings.fastApprox);
@@ -309,7 +309,7 @@ void ImageEffect_InPainting_Dialog::resetValues()
 
 void ImageEffect_InPainting_Dialog::processCImgURL(const TQString& url)
 {
-    KApplication::kApplication()->invokeBrowser(url);
+    TDEApplication::kApplication()->invokeBrowser(url);
 }
 
 void ImageEffect_InPainting_Dialog::prepareEffect()
@@ -415,7 +415,7 @@ void ImageEffect_InPainting_Dialog::putFinalData(void)
 
 void ImageEffect_InPainting_Dialog::slotUser3()
 {
-    KURL loadInpaintingFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    KURL loadInpaintingFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                             TQString( "*" ), this,
                                             TQString( i18n("Photograph Inpainting Settings File to Load")) );
     if( loadInpaintingFile.isEmpty() )
@@ -446,7 +446,7 @@ void ImageEffect_InPainting_Dialog::slotUser3()
 
 void ImageEffect_InPainting_Dialog::slotUser2()
 {
-    KURL saveRestorationFile = KFileDialog::getSaveURL(KGlobalSettings::documentPath(),
+    KURL saveRestorationFile = KFileDialog::getSaveURL(TDEGlobalSettings::documentPath(),
                                             TQString( "*" ), this,
                                             TQString( i18n("Photograph Inpainting Settings File to Save")) );
     if( saveRestorationFile.isEmpty() )
