@@ -7,7 +7,7 @@
  * Description : Color management setup tab.
  *
  * Copyright (C) 2005-2007 by F.J. Cruz <fj.cruz@supercable.es>
- * Copyright (C) 2005-2009 by Gilles Caulier <caulier dot gilles at gmail dot com> 
+ * Copyright (C) 2005-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,18 +45,18 @@
 
 // KDE includes.
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdialog.h>
 #include <kdialogbase.h>
 #include <kurlrequester.h>
 #include <klineedit.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kcombobox.h>
-#include <kapplication.h>
-#include <kmessagebox.h>
+#include <tdeapplication.h>
+#include <tdemessagebox.h>
 #include <kurllabel.h>
 #include <kiconloader.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <kstandarddirs.h>
 
 // lcms includes.
@@ -165,8 +165,8 @@ SetupICC::SetupICC(TQWidget* parent, KDialogBase* dialog )
     KURLLabel *lcmsLogoLabel = new KURLLabel(colorPolicy);
     lcmsLogoLabel->setText(TQString());
     lcmsLogoLabel->setURL("http://www.littlecms.com");
-    KGlobal::dirs()->addResourceType("logo-lcms", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("logo-lcms", "logo-lcms.png");
+    TDEGlobal::dirs()->addResourceType("logo-lcms", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("logo-lcms", "logo-lcms.png");
     lcmsLogoLabel->setPixmap( TQPixmap( directory + "logo-lcms.png" ) );
     TQToolTip::add(lcmsLogoLabel, i18n("Visit Little CMS project website"));
 
@@ -240,7 +240,7 @@ SetupICC::SetupICC(TQWidget* parent, KDialogBase* dialog )
     grid2->addMultiCellWidget(d->infoMonitorProfiles, 1, 1, 3, 3);
 
     TQLabel *workIcon     = new TQLabel(d->profilesGB);
-    workIcon->setPixmap(SmallIcon("tablet"));
+    workIcon->setPixmap(SmallIcon("input-tablet"));
     TQLabel *workProfiles = new TQLabel(i18n("Workspace:"), d->profilesGB);
     d->workProfilesKC    = new SqueezedComboBox(d->profilesGB);
     workProfiles->setBuddy(d->workProfilesKC);
@@ -257,7 +257,7 @@ SetupICC::SetupICC(TQWidget* parent, KDialogBase* dialog )
     grid2->addMultiCellWidget(d->infoWorkProfiles, 2, 2, 3, 3);
 
     TQLabel *inIcon     = new TQLabel(d->profilesGB);
-    inIcon->setPixmap(SmallIcon("camera"));
+    inIcon->setPixmap(SmallIcon("camera-photo"));
     TQLabel *inProfiles = new TQLabel(i18n("Input:"), d->profilesGB);
     d->inProfilesKC    = new SqueezedComboBox(d->profilesGB);
     inProfiles->setBuddy(d->inProfilesKC);
@@ -273,7 +273,7 @@ SetupICC::SetupICC(TQWidget* parent, KDialogBase* dialog )
     grid2->addMultiCellWidget(d->infoInProfiles, 3, 3, 3, 3);
 
     TQLabel *proofIcon     = new TQLabel(d->profilesGB);
-    proofIcon->setPixmap(SmallIcon("printer1"));
+    proofIcon->setPixmap(SmallIcon("printer"));
     TQLabel *proofProfiles = new TQLabel(i18n("Soft proof:"), d->profilesGB);
     d->proofProfilesKC    = new SqueezedComboBox(d->profilesGB);
     proofProfiles->setBuddy(d->proofProfilesKC);
@@ -378,12 +378,12 @@ SetupICC::~SetupICC()
 
 void SetupICC::processLCMSURL(const TQString& url)
 {
-    KApplication::kApplication()->invokeBrowser(url);
+    TDEApplication::kApplication()->invokeBrowser(url);
 }
 
 void SetupICC::applySettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("Color Management");
 
     config->writeEntry("EnableCM", d->enableColorManagement->isChecked());
@@ -417,7 +417,7 @@ void SetupICC::applySettings()
 
 void SetupICC::readSettings(bool restore)
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("Color Management");
 
     if (!restore)
@@ -493,8 +493,8 @@ void SetupICC::fillCombos(const TQString& path, bool report)
     }
 
     // Look the ICC color-space profile path include with digiKam dist.
-    KGlobal::dirs()->addResourceType("profiles", KGlobal::dirs()->kde_default("data") + "digikam/profiles");
-    TQString digiKamProfilesPath = KGlobal::dirs()->findResourceDir("profiles", "srgb.icm");
+    TDEGlobal::dirs()->addResourceType("profiles", TDEGlobal::dirs()->kde_default("data") + "digikam/profiles");
+    TQString digiKamProfilesPath = TDEGlobal::dirs()->findResourceDir("profiles", "srgb.icm");
     TQDir digiKamProfilesDir(digiKamProfilesPath, "*.icc;*.icm", TQDir::Files);
     const TQFileInfoList* digiKamFiles = digiKamProfilesDir.entryInfoList();
     DDebug() << "Scanning ICC profiles included with digiKam: " << digiKamProfilesPath << endl;
@@ -706,7 +706,7 @@ void SetupICC::slotToggleManagedView(bool b)
 
 bool SetupICC::iccRepositoryIsValid()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("Color Management");
 
     // If color management is disable, no need to check anymore.
